# Metabolitics

[![Build Status](https://travis-ci.org/MuhammedHasan/metabolitics.svg?branch=master)](https://travis-ci.org/MuhammedHasan/metabolitics) [![Documentation Status](https://readthedocs.org/projects/metabolitics/badge/?version=latest)](http://metabolitics.readthedocs.io/en/latest/?badge=latest) [![codecov](https://codecov.io/gh/MuhammedHasan/metabolitics/branch/master/graph/badge.svg)](https://codecov.io/gh/MuhammedHasan/metabolitics)

...

## Installation

You can install `metabolitics` with `pip`:

```
pip install metabolitics
```

## Examples

...

For more features, You can check the documentation.

## Documentation

The documentation of the project avaiable in http://metabolitics.rtfd.io .


